@@ -320,10 +320,6 @@ public:
      */
     void resetPackageDependsStatus(const int index);
 
-public:
-
-    QList<QByteArray> m_errorIndex;        //wine依赖错误的包的下标
-
 //// 依赖查找 获取等相关函数
 private:
 
@@ -339,17 +335,18 @@ private:
     const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture,
                                                          const QApt::DependencyItem &candicate);
     const PackageDependsStatus checkDependsPackageStatus(QSet<QString> &choosed_set, const QString &architecture,
-                                                         const QApt::DependencyInfo &dependencyInfo);
+                                                         const QApt::DependencyInfo &dependencyInfo, const QString &providesName = QString::null);
     /**
      * @brief packageCandidateChoose   查找包的依赖候选
      * @param choosed_set   包的依赖候选的集合
      * @param debArch       包的架构
      * @param dependsList   依赖列表
+       @param levelInfo     提供用于打印的软件包查找层级依赖信息
      */
     void packageCandidateChoose(QSet<QString> &choosed_set, const QString &debArch,
-                                const QList<QApt::DependencyItem> &dependsList);
+                                const QList<QApt::DependencyItem> &dependsList, const QString& levelInfo);
     void packageCandidateChoose(QSet<QString> &choosed_set, const QString &debArch,
-                                const QApt::DependencyItem &candidateItem);
+                                const QApt::DependencyItem &candidateItem, const QString &levelInfo);
 
     /**
      * @brief isInstalledConflict 是否存在下载冲突
@@ -374,6 +371,18 @@ private:
                                            const QList<DependencyItem> &conflicts,
                                            const QList<DependencyItem> &replaces);
 
+//// 依赖查找 获取查找包是否为消极的反向依赖
+private:
+    /**
+     * @brief isNegativeReverseDepend 判断软件包 `reverseDepend` 是否是 `packageName` 的消极依赖包，
+     *      例如 冲突(Conflict)/替换(Replace)/破坏(Breaks) 这些包在卸载时将被跳过，
+     *      在 依赖(Depends) 字段设置包将不会被视为消极包。
+     * @param packageName   当前处理的软件包
+     * @param reverseDepend `packageName` 的反向依赖包
+     * @return `reverseDepend` 是否为 `packageName` 的消极依赖
+     */
+    bool isNegativeReverseDepend(const QString &packageName, const QApt::Package *reverseDepend);
+
 private:
     /**
      * @brief packageWithArch 从指定的架构上打包
@@ -385,6 +394,16 @@ private:
     QApt::Package *packageWithArch(const QString &packageName, const QString &sysArch,
                                    const QString &annotation = QString());
 
+    /**
+     * @brief checkPackageArchValid 检测通过包名 \a packageName 获取的软件包 \a package 架构
+     *      是否支持建议架构 \a suggestArch
+     * @param package       软件包
+     * @param packageName   软件包名称
+     * @param resloveArch   解析建议的软件包名称
+     * @return 软件包 \a package 支持 \a suggestArch 架构
+     */
+    bool checkPackageArchValid(const QApt::Package *package, const QString &packageName, const QString &suggestArch);
+
 private:
 
     // 卸载deepin-wine-plugin-virture 时无法卸载deepin-wine-helper. Temporary solution：Special treatment for these package
@@ -505,7 +524,14 @@ private:
      */
     void getBlackApplications();
 
+    /**
+       @brief 过滤已安装或无需更新的Wine软件包
+     */
+    void filterNeedInstallWinePackage(QStringList &dependList, const DebFile &debFile, const QHash<QString, DependencyInfo>& dependInfoMap);
+
 private:
+    QMap<QByteArray, int> m_errorIndex;        //wine依赖错误的包的下标 QMap<MD5, DebListModel::DependsAuthStatus>
+
     //存放包路径的列表
     QList<QString> m_preparedPackages       = {};
 
@@ -552,6 +578,13 @@ private:
     QMap<QByteArray, QPair<QList<DependInfo>, QList<DependInfo>>> m_dependsPackages;
     DependInfo m_dinfo; //依赖包的包名及版本
 
+    /**
+       @brief m_loopErrorDeepends 循环判断依赖时缓存非 Ok 的前置包状态
+        用于对 OR 或依赖及 Provides 虚包依赖在循环中依赖中返回前置已检测的包状态，
+        而不是直接返回 Ok .
+     */
+    QHash<QString, int> m_loopErrorDeepends;
+
     // wine应用处理的下标
     int m_DealDependIndex = -1;
 
