@@ -9,6 +9,7 @@
 #include "view/pages/AptConfigMessage.h"
 #include "view/pages/settingdialog.h"
 #include "utils/utils.h"
+#include "utils/hierarchicalverify.h"
 #include "singleInstallerApplication.h"
 
 #include <DDialog>
@@ -230,6 +231,9 @@ void DebListModel::slotDealDependResult(int authType, int dependIndex, const QSt
         break;
     case DebListModel::AuthDependsErr:                      //安装失败后，状态的修改由debinstaller进行处理
         break;
+    case DebListModel::VerifyDependsErr:                    //依赖包分级管控验证签名失败，弹出分级设置提示框
+        showHierarchicalVerifyWindow();
+        break;
     default:
         break;
     }
@@ -372,6 +376,8 @@ void DebListModel::slotUninstallPackage(const int index)
     if (!debFile.isValid())
         return;
     const QStringList rdepends = m_packagesManager->packageReverseDependsList(debFile.packageName(), debFile.architecture()); //检查是否有应用依赖到该包
+    qInfo() << QString("Will remove reverse depends before remove %1 , Lists:").arg(debFile.packageName()) << rdepends;
+    
     Backend *backend = PackageAnalyzer::instance().backendPtr();
     for (const auto &r : rdepends) {                                        // 卸载所有依赖该包的应用（二者的依赖关系为depends）
         if (backend->package(r)) {
@@ -442,6 +448,11 @@ int DebListModel::checkDependsStatus(const QString &package_path)
 
 int DebListModel::checkDigitalSignature(const QString &package_path)
 {
+    // 分级管控可用时，交由分级管控进行签名验证
+    if (HierarchicalVerify::instance()->isValid()) {
+        return Utils::VerifySuccess;
+    }
+
     const auto stat = m_packagesManager->checkDependsStatus(package_path); //获取包的依赖状态
     if (stat.isBreak() || stat.isAuthCancel())
         return Utils::VerifySuccess;
@@ -507,6 +518,8 @@ void DebListModel::reset()
     m_packageFailCode.clear();                          //清空错误原因列表
     m_packageFailReason.clear();
     m_packagesManager->reset();                         //重置packageManager
+
+    m_hierarchicalVerifyError = false;                  // 复位分级管控安装状态
 }
 
 int DebListModel::getInstallFileSize()
@@ -531,6 +544,12 @@ void DebListModel::bumpInstallIndex()
         emit signalWorkerFinished();                                                  //发送安装完成信号
         emit signalWorkerProgressChanged(100);                                        //修改安装进度
         emit signalTransactionProgressChanged(100);
+
+        // 安装结束，弹出分级管控信息提示框
+        if (m_hierarchicalVerifyError) {
+            showHierarchicalVerifyWindow();
+            m_hierarchicalVerifyError = false;
+        }
         return;
     }
     ++ m_operatingStatusIndex;
@@ -549,7 +568,7 @@ void DebListModel::bumpInstallIndex()
 void DebListModel::slotTransactionErrorOccurred()
 {
     if (WorkerProcessing != m_workerStatus) {
-        qWarning() << "installer status error";
+        qWarning() << "installer status error" << m_workerStatus;
     }
     Transaction *transaction = qobject_cast<Transaction *>(sender());
     if (!transaction)
@@ -608,8 +627,15 @@ QString DebListModel::packageFailedReason(const int idx) const
         return tr("The administrator has set policies to prevent installation of this package");
     if (dependStatus.isBreak() || dependStatus.isAuthCancel()) {                                            //依赖状态错误
         if (!dependStatus.package.isEmpty() || !m_brokenDepend.isEmpty()) {
-            if (m_packagesManager->m_errorIndex.contains(md5))     //修改wine依赖的标记方式
-                return tr("Failed to install %1").arg(m_brokenDepend); //wine依赖安装失败
+            if (m_packagesManager->m_errorIndex.contains(md5)) {    //修改wine依赖的标记方式
+                auto ret = static_cast<DebListModel::DependsAuthStatus>(m_packagesManager->m_errorIndex.value(md5));
+                switch (ret) {
+                   case DebListModel::VerifyDependsErr:
+                       return m_brokenDepend + tr("Invalid digital signature");
+                    default:
+                        return tr("Failed to install %1").arg(m_brokenDepend); //wine依赖安装失败
+                }
+            }
             return tr("Broken dependencies: %1").arg(dependStatus.package);                         //依赖不满足
         }
 
@@ -618,12 +644,6 @@ QString DebListModel::packageFailedReason(const int idx) const
             return tr("Broken dependencies: %1").arg(conflictStatus.unwrap()); //依赖冲突
     }
 
-    if (m_packageOperateStatus.contains(md5) && m_packageOperateStatus[md5] == Failed)
-        qWarning() << "package operate status failed";
-    //判断当前这个包是否错误
-    if (!m_packageFailCode.contains(md5))
-        qWarning() << "DebListModel:" << "failed to get reason" << m_packageFailCode.size() << idx;
-
     // 修改map存储的数据格式，将错误原因与错误代码与包绑定，而非与下标绑定
     return workerErrorString(m_packageFailCode[md5], m_packageFailReason[md5]);             //根据错误代码和错误原因返回具体的错误原因
 }
@@ -631,7 +651,7 @@ QString DebListModel::packageFailedReason(const int idx) const
 void DebListModel::slotTransactionFinished()
 {
     if (m_workerStatus == WorkerProcessing) {
-        qWarning() << "installer status error";
+        qWarning() << "installer status still processing";
     }
     // 获取trans指针
     Transaction *transaction = qobject_cast<Transaction *>(sender());
@@ -649,9 +669,24 @@ void DebListModel::slotTransactionFinished()
     if (transaction->exitStatus()) {
         //安装失败
         qWarning() << transaction->error() << transaction->errorDetails() << transaction->errorString();
-        //保存错误原因和错误代码
+        // 检测错误信息是否包含分级管控错误码，若存在，则当前错误为分级管控验证签名不通过
+        QString errorInfo = transaction->errorDetails();
+        if (errorInfo.isEmpty()) {
+            errorInfo = transaction->errorString();
+        }
+        QString sPackageName = m_packagesManager->m_preparedPackages[m_operatingIndex];
+        bool verifyError = HierarchicalVerify::instance()->checkTransactionError(sPackageName, errorInfo);
+
+        // 检测安装失败时，弹出对话框提示
+        if (verifyError) {
+            // 安装结束后再弹出提示对话框
+            m_hierarchicalVerifyError = true;
+        }
+
+        // 保存错误原因和错误代码
         // 修改map存储的数据格式，将错误原因与错误代码与包绑定，而非与下标绑定
-        m_packageFailCode[m_operatingPackageMd5] = transaction->error();
+        m_packageFailCode[m_operatingPackageMd5] =
+            verifyError ? static_cast<int>(DebListModel::DigitalSignatureError) : static_cast<int>(transaction->error());
         m_packageFailReason[m_operatingPackageMd5] = transaction->errorString();
 
         //刷新操作状态
@@ -681,7 +716,7 @@ void DebListModel::slotTransactionFinished()
 void DebListModel::slotDependsInstallTransactionFinished()//依赖安装关系满足
 {
     if (m_workerStatus == WorkerProcessing) {
-        qWarning() << "installer status error";
+        qWarning() << "installer status still processing";
     }
     Transaction *transaction = qobject_cast<Transaction *>(sender());
     if (!transaction)
@@ -753,6 +788,8 @@ void DebListModel::installDebs()
     DebFile deb(m_packagesManager->package(m_operatingIndex)) ;
     if (!deb.isValid())
         return;
+    qInfo() << QString("Prepare to install %1, ver: %2, arch: %3").arg(deb.packageName()).arg(deb.version()).arg(deb.architecture());
+
     Q_ASSERT_X(m_workerStatus == WorkerProcessing, Q_FUNC_INFO, "installer status error");
     Q_ASSERT_X(m_currentTransaction.isNull(), Q_FUNC_INFO, "previous transaction not finished");
     //在判断dpkg启动之前就发送开始安装的信号，并在安装信息中输出 dpkg正在运行的信息。
@@ -794,6 +831,8 @@ void DebListModel::installDebs()
 
         // 获取到所有的依赖包 准备安装
         const QStringList availableDepends = m_packagesManager->packageAvailableDepends(m_operatingIndex);
+        qInfo() << QString("Prepare install package: %1 , install depends: ").arg(deb.packageName()) << availableDepends;
+
         //获取到可用的依赖包并根据后端返回的结果判断依赖包的安装结果
         for (auto const &p : availableDepends) {
             if (p.contains(" not found")) {                             //依赖安装失败
@@ -803,10 +842,14 @@ void DebListModel::installDebs()
                 m_packageFailReason.insert(m_operatingPackageMd5, p);
                 emit signalAppendOutputInfo(m_packagesManager->package(m_operatingIndex) + "\'s depend " + " " + p);  //输出错误原因
                 bumpInstallIndex();                                     //开始安装下一个包或结束安装
+
+                qWarning() << QString("Packge %1 install failed, not found depend package: %2").arg(deb.packageName()).arg(p);
                 return;
             }
             backend->markPackageForInstall(p);                          //开始安装依赖包
         }
+        // 打印待安装的软件包信息
+        printDependsChanges();
 
         transaction = backend->commitChanges();
         if (!transaction)
@@ -881,11 +924,13 @@ void DebListModel::showNoDigitalErrWindowInDdimProcess(void (DebListModel::*fail
 
     auto fullPath = m_packagesManager->package(m_operatingIndex);
     QFileInfo info(fullPath);
-    Ddialog->setMessage(QString(tr("Failed to install %1: no valid digital singature").arg(info.fileName())));
+    Ddialog->setMessage(QString(tr("Failed to install %1: no valid digital signature").arg(info.fileName())) + QString("!"));
 
     //消息框reject后的操作，包括点击取消按钮、关闭图标、按ESC退出
     std::function<void(void)> rejectOperate = [this, Ddialog, failedFunction]() {
-        (this->*failedFunction)();
+        if (failedFunction) {
+            (this->*failedFunction)();
+        }
         Ddialog->deleteLater();
     };
 
@@ -948,16 +993,19 @@ void DebListModel::showNoDigitalErrWindow()
     connect(btnProceedControlCenter, &DPushButton::clicked, Ddialog, &DDialog::deleteLater);
 }
 
-void DebListModel::showDigitalErrWindow()
+void DebListModel::showDigitalErrWindow(bool recordError)
 {
     if (SingleInstallerApplication::mode == SingleInstallerApplication::DdimChannel) {
-        showNoDigitalErrWindowInDdimProcess(&DebListModel::slotDigitalSignatureError);
+        // 不记录错误时仅提示，不涉及状态切换及更新记录
+        showNoDigitalErrWindowInDdimProcess(recordError ? &DebListModel::slotDigitalSignatureError : nullptr);
         return;
     }
 
     //批量安装时，如果不是最后一个包，则不弹窗，只记录详细错误原因。
     if (m_operatingIndex < m_packagesManager->m_preparedPackages.size() - 1) {
-        digitalVerifyFailed(DigitalSignatureError);     //刷新安装错误，并记录错误原因
+        if (recordError) {
+            digitalVerifyFailed(DigitalSignatureError);     //刷新安装错误，并记录错误原因
+        }
         return;
     }
     DDialog *Ddialog = new DDialog();
@@ -972,7 +1020,7 @@ void DebListModel::showDigitalErrWindow()
 
     // 设置弹出窗口显示的信息
     Ddialog->setTitle(tr("Unable to install"));
-    Ddialog->setMessage(QString(tr("This package does not have a valid digital signature")));
+    Ddialog->setMessage(QString(tr("This package does not have a valid digital signature")) + QString("!"));
     Ddialog->setIcon(QIcon::fromTheme("di_popwarning"));
     Ddialog->addButton(QString(tr("OK", "button")), true, DDialog::ButtonNormal);
     Ddialog->show();
@@ -981,8 +1029,10 @@ void DebListModel::showDigitalErrWindow()
     btnOK->setFocus();
 
     //窗口退出操作，包括所有可以退出此窗口的操作
-    std::function<void(void)> exitOperate = [this, Ddialog]() {
-        this->slotDigitalSignatureError();
+    std::function<void(void)> exitOperate = [this, Ddialog, recordError]() {
+        if (recordError) {
+            this->slotDigitalSignatureError();
+        }
         Ddialog->deleteLater();
     };
 
@@ -1072,27 +1122,35 @@ void DebListModel::slotShowDevelopModeWindow()
         qInfo() << "OS version:" << osVerStr;
     }
 
-    //2.打开控制中心
-    if (osVerStr == "20") { // V20模式
-        QString command = "dbus-send --print-reply "
-                          "--dest=com.deepin.dde.ControlCenter "
-                          "/com/deepin/dde/ControlCenter "
-                          "com.deepin.dde.ControlCenter.ShowModule "
-                          "\"string:commoninfo\"";
-        unlock->startDetached(command);
-        unlock->waitForFinished();
-    } else if (osVerStr == "23") { // V23模式
-        if (unlock->exitCode() != QProcess::NormalExit) {
-            QString command = "dbus-send --print-reply "
-                              "--dest=org.deepin.dde.ControlCenter1 "
-                              "/org/deepin/dde/ControlCenter1 "
-                              "org.deepin.dde.ControlCenter1.ShowPage "
-                              "\"string:commoninfo\"";
-            unlock->startDetached(command);
-            unlock->waitForFinished();
+    // 2.打开控制中心
+    if (osVerStr == "20") {  // V20模式
+        QDBusInterface interface("com.deepin.dde.ControlCenter", "/com/deepin/dde/ControlCenter", "com.deepin.dde.ControlCenter");
+        if (interface.isValid()) {
+            interface.call("ShowPage", "commoninfo", "Developer Mode");
         }
+
+        QDBusError error = interface.lastError();
+        if (error.isValid()) {
+            qWarning() << QString("DBus ControlCenter.ShowPage failed, Type: %1 MSG: %2").arg(error.type()).arg(error.message());
+        }
+
+    } else if (osVerStr == "23") {  // V23模式
+        if (unlock->exitCode() != QProcess::NormalExit) {
+            QDBusInterface interface(
+                "org.deepin.dde.ControlCenter1", "/org/deepin/dde/ControlCenter1", "org.deepin.dde.ControlCenter1");
+            if (interface.isValid()) {
+                interface.call("ShowPage", "commoninfo", "Developer Mode");
+            }
+
+            QDBusError error = interface.lastError();
+            if (error.isValid()) {
+                qWarning()
+                    << QString("DBus ControlCenter.ShowPage failed, Type: %1 MSG: %2").arg(error.type()).arg(error.message());
+            }
+        }
+
     } else {
-        qWarning() << "Unknown OS version, connot open dde-control-center";
+        qWarning() << qPrintable("Unknown OS version, connot open dde-control-center");
     }
 
     unlock->deleteLater();
@@ -1156,6 +1214,11 @@ void DebListModel::checkSystemVersion()
 
 bool DebListModel::checkDigitalSignature()
 {
+    // 分级管控可用时，交由分级管控进行签名验证
+    if (HierarchicalVerify::instance()->isValid()) {
+        return true;
+    }
+
     const auto stat = m_packagesManager->getPackageDependsStatus(m_operatingIndex); //获取包的依赖状态
     if (stat.isBreak() || stat.isAuthCancel())
         return true;
@@ -1526,8 +1589,8 @@ void DebListModel::showProhibitWindow()
     Ddialog->setIcon(QIcon::fromTheme("di_popwarning"));
     Ddialog->addButton(QString(tr("OK", "button")), true, DDialog::ButtonNormal);
     Ddialog->show();
-    QPushButton *btnOK = qobject_cast<QPushButton *>(Ddialog->getButton(0));
 
+    QPushButton *btnOK = qobject_cast<QPushButton *>(Ddialog->getButton(0));
     btnOK->setFocusPolicy(Qt::TabFocus);
     btnOK->setFocus();
 
@@ -1547,6 +1610,59 @@ void DebListModel::showProhibitWindow()
     connect(Ddialog, &DDialog::rejected, exitOperate);
 }
 
+/**
+   @brief 弹出分级管控安全等级设置引导提示窗口
+ */
+void DebListModel::showHierarchicalVerifyWindow()
+{
+    if (!HierarchicalVerify::instance()->isValid()) {
+        return;
+    }
+
+    DDialog *dialog = new DDialog();
+    // 限制显示宽度
+    dialog->setFixedWidth(380);
+    dialog->setFocusPolicy(Qt::TabFocus);
+    dialog->setModal(true);
+    dialog->setWindowFlag(Qt::WindowStaysOnTopHint);
+
+    // 设置弹出窗口显示的信息
+    dialog->setTitle(tr("Unable to install"));
+    dialog->setMessage(tr("This package does not have a valid digital signature and has been blocked from installing/running. "
+                          "Go to Security Center > Tools > App Security to change the settings."));
+    dialog->setIcon(QIcon::fromTheme("di_popwarning"));
+    dialog->addButton(QString(tr("Cancel", "button")), false, DDialog::ButtonNormal);
+    dialog->addButton(QString(tr("Proceed", "button")), true, DDialog::ButtonRecommend);
+    dialog->show();
+
+    // 拷贝自 ddialog.cpp 用于设置默认对话框高度，避免在大字号/高缩放比下显示不全，在 show() 之后调用。
+    QLabel *msgLabel = dialog->findChild<QLabel *>("MessageLabel");
+    if (msgLabel) {
+        auto dialogStyle = dialog->style();
+        if (dialogStyle) {
+            QSize sz = dialogStyle->itemTextRect(msgLabel->fontMetrics(), msgLabel->rect(),
+                                                 Qt::TextWordWrap, false, msgLabel->text()).size();
+            msgLabel->setMinimumHeight(qMax(sz.height(), msgLabel->sizeHint().height()));
+        }
+    }
+
+    QPushButton *btnPorceed = qobject_cast<QPushButton *>(dialog->getButton(1));
+    btnPorceed->setFocusPolicy(Qt::TabFocus);
+    btnPorceed->setFocus();
+
+    //窗口退出操作，包括所有可以退出此窗口的操作
+    std::function<void(void)> exitOperate = [dialog]() {
+        dialog->deleteLater();
+    };
+
+    connect(dialog, &DDialog::finished, [dialog](int result){
+        if (QDialog::Accepted == result) {
+            HierarchicalVerify::instance()->proceedDefenderSafetyPage();
+        }
+        dialog->deleteLater();
+    });
+}
+
 bool DebListModel::checkBlackListApplication()
 {
     PackageDependsStatus dependsStat = m_packagesManager->getPackageDependsStatus(m_operatingIndex);
@@ -1574,6 +1690,46 @@ DebListModel::~DebListModel()
     delete m_procInstallConfig;
 }
 
+/**
+   @brief 打印待安装的软件包信息，将根据安装、升级、卸载等分类分别打印对应变更的软件包
+ */
+void DebListModel::printDependsChanges()
+{
+    auto *const backend = PackageAnalyzer::instance().backendPtr();
+    if (!backend) {
+        return;
+    }
+
+    auto changeList = backend->markedPackages();
+    if (changeList.isEmpty()) {
+        return;
+    }
+
+    static QMap<int, QString> tagTable = { {Package::IsManuallyHeld, "Package::IsManuallyHeld"},
+                                           {Package::NewInstall, "Package::NewInstall"},
+                                           {Package::ToReInstall, "Package::ToReInstall"},
+                                           {Package::ToUpgrade, "Package::ToUpgrade"},
+                                           {Package::ToDowngrade, "Package::ToDowngrade"},
+                                           {Package::ToRemove, "Package::ToRemove"} };
+    QMap<int, QStringList> changeInfo;
+
+    for (const Package *package : changeList) {
+        int flags = package->state();
+        int status = flags & (Package::IsManuallyHeld |
+                              Package::NewInstall |
+                              Package::ToReInstall |
+                              Package::ToUpgrade |
+                              Package::ToDowngrade |
+                              Package::ToRemove);
+        changeInfo[status] << QString("%1, %2, %3").arg(package->name()).arg(package->version()).arg(package->architecture());
+    }
+
+    qInfo() << "Install depends details:";
+    for (auto info = changeInfo.begin(); info != changeInfo.end(); info++) {
+        qInfo() << tagTable[info.key()] << info.value();
+    }
+}
+
 Dialog::Dialog()
 {
 }
