@@ -93,7 +93,11 @@ QList<DependencyItem> deb_conflicts()
 QList<DependencyItem> deb_conflicts_null()
 {
     return {};
+}
 
+QList<DependencyItem> deb_replaces_null()
+{
+    return {};
 }
 
 Package *stub_packageWithArch(QString, QString, QString)
@@ -329,11 +333,6 @@ void UT_packagesManager::TearDown()
 {
     stub.set(ADDR(PackagesManager, rmTempDir), stub_is_open_false);
 
-    for (auto pkg : PackageAnalyzer::instance().backendPtr()->availablePackages()) {
-        delete pkg;
-        pkg =  nullptr;
-    }
-
     delete m_packageManager;
 }
 
@@ -549,6 +548,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageConflictStat)
 
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stub_getPackageDependsStatus);
     stub.set(ADDR(DebFile, conflicts), deb_conflicts_null);
+    stub.set(ADDR(DebFile, replaces), deb_replaces_null);
 
     stub.set(ADDR(PackagesManager, dealPackagePath), stub_dealPackagePath);
     stub.set(ADDR(PackagesManager, dealInvalidPackage), stub_dealInvalidPackage);
@@ -827,12 +827,12 @@ TEST_F(UT_packagesManager, PackageManager_UT_isConflictSatisfy_0003)
     ASSERT_FALSE(cr.is_ok());
 }
 
-const ConflictResult stub_isConflictSatisfy(const QString &, const QList<QApt::DependencyItem> &)
+const ConflictResult stub_isConflictSatisfy(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &)
 {
     return ConflictResult::ok("1");
 }
 
-const ConflictResult stub_isConflictSatisfy_error(const QString &, const QList<QApt::DependencyItem> &)
+const ConflictResult stub_isConflictSatisfy_error(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &)
 {
     return ConflictResult::err("1");
 }
@@ -852,9 +852,11 @@ TEST_F(UT_packagesManager, PackageManager_UT_isConflictSatisfy_0004)
     stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
 
     stub.set(ADDR(PackagesManager, isInstalledConflict), stub_isInstalledConflict_ok);
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     ConflictResult cr = m_packageManager->isConflictSatisfy("i386", &package);
     ASSERT_TRUE(cr.is_ok());
@@ -969,6 +971,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_DealDependResult)
     stub.set(ADDR(DebFile, depends), deb_depends);
     stub.set(ADDR(PackagesManager, isArchError), ut_isArchError_false);
     stub.set(ADDR(DebFile, conflicts), deb_conflicts);
+    stub.set(ADDR(DebFile, replaces), deb_replaces_null);
     stub.set((QString(DebFile::*)(const QString & name) const)ADDR(DebFile, controlField), ut_controlField);
     stub.set(ADDR(DependGraph, getBestInstallQueue), stub_getBestInstallQueue);
 
@@ -1164,7 +1167,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_getPackageDependsStatus_05)
     stub.set(ADDR(Package, isInstalled), stub_isInstalled);
 
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy_error);
 
     PackageDependsStatus pd = m_packageManager->getPackageDependsStatus(0);
@@ -1187,7 +1190,8 @@ const PackageDependsStatus stub_checkDependsPackageStatus_ok(QSet<QString> &, co
 
 const PackageDependsStatus stub_checkDependsPackageStatus_DI(QSet<QString> &,
                                                              const QString &,
-                                                             const DependencyInfo &)
+                                                             const DependencyInfo &,
+                                                             const QString &)
 {
     return PackageDependsStatus::_break("1");
 }
@@ -1220,7 +1224,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_getPackageDependsStatus_06)
     stub.set(ADDR(PackagesManager, dealInvalidPackage), stub_dealInvalidPackage);
     stub.set(ADDR(PackagesManager, isBlackApplication), stub_isBlackApplication_false);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
@@ -1229,7 +1233,8 @@ TEST_F(UT_packagesManager, PackageManager_UT_getPackageDependsStatus_06)
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &,
                                                              const QString &,
-                                                             const DependencyInfo &))
+                                                             const DependencyInfo &,
+                                                             const QString &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus_DI);
 
 
@@ -1276,6 +1281,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_getPackageDependsStatus_07)
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), package_package);
     stub.set(ADDR(Package, multiArchType), ut_packagesManager_multiArchType);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(DebFile, replaces), deb_replaces_null);
     stub.set((QString(DebFile::*)(const QString & name) const)ADDR(DebFile, controlField), ut_controlField);
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
@@ -1284,12 +1290,13 @@ TEST_F(UT_packagesManager, PackageManager_UT_getPackageDependsStatus_07)
     stub.set(ADDR(PackagesManager, dealInvalidPackage), stub_dealInvalidPackage);
     stub.set(ADDR(PackagesManager, isBlackApplication), stub_isBlackApplication_false);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &,
                                                              const QString &,
-                                                             const DependencyInfo &))
+                                                             const DependencyInfo &,
+                                                             const QString &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus_DI);
 
     stub.set(ADDR(QThread, isRunning), stub_isRunning);
@@ -1423,10 +1430,16 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageReverseDependsList)
     ASSERT_TRUE(ads.isEmpty());
 }
 
+bool stub_isNegativeReverseDepend(const QString &packageName, const QApt::Package *reverseDepend)
+{
+    return false;
+}
+
 TEST_F(UT_packagesManager, PackageManager_UT_packageReverseDependsList_1)
 {
     stub.set(ADDR(DebFile, depends), deb_depends);
     stub.set(ADDR(DebFile, conflicts), deb_conflicts);
+    stub.set(ADDR(DebFile, replaces), deb_replaces_null);
 
     stub.set(ADDR(Package, installedVersion), package_installedVersion);
     stub.set(ADDR(Package, compareVersion), package_compareVersion);
@@ -1440,6 +1453,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageReverseDependsList_1)
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stub_getPackageDependsStatus);
     stub.set(ADDR(PackagesManager, dealPackagePath), stub_dealPackagePath);
     stub.set(ADDR(PackagesManager, dealInvalidPackage), stub_dealInvalidPackage);
+    stub.set(ADDR(PackagesManager, isNegativeReverseDepend), stub_isNegativeReverseDepend);
 
     usleep(10 * 1000);
     m_packageManager->appendPackage({"/"});
@@ -1552,6 +1566,7 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageReverseDependsList_5)
     stub.set(ADDR(PackagesManager, getPackageDependsStatus), stub_getPackageDependsStatus);
     stub.set(ADDR(PackagesManager, dealPackagePath), stub_dealPackagePath);
     stub.set(ADDR(PackagesManager, dealInvalidPackage), stub_dealInvalidPackage);
+    stub.set(ADDR(PackagesManager, isNegativeReverseDepend), stub_isNegativeReverseDepend);
 
     usleep(10 * 1000);
     m_packageManager->appendPackage({"/"});
@@ -2000,21 +2015,24 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageCandidateChoose)
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
 
+    stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, installedVersion), package_installedVersion);
     stub.set(ADDR(Package, compareVersion), ut_packagesManager_compareVersion);
     stub.set(ADDR(Package, name), package_name);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
     stub.set(ADDR(Package, depends), deb_conflicts_null);
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), packagesManager_package);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
                                                              const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus);
 
-    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList);
+    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList, QString());
     EXPECT_EQ("", debArch);
     EXPECT_EQ(1, choosed_set.size());
     EXPECT_EQ(1, cadicateList.size());
@@ -2033,21 +2051,24 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageCandidateChoose_1)
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
 
+    stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, installedVersion), package_version);
     stub.set(ADDR(Package, compareVersion), package_compareVersion1);
     stub.set(ADDR(Package, name), package_name);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
     stub.set(ADDR(Package, depends), deb_conflicts_null);
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), packagesManager_package);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
                                                              const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus);
 
-    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList);
+    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList, QString());
     EXPECT_EQ("", debArch);
     EXPECT_EQ(1, choosed_set.size());
     EXPECT_EQ(1, cadicateList.size());
@@ -2066,21 +2087,24 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageCandidateChoose_2)
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
 
+    stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, installedVersion), package_version);
     stub.set(ADDR(Package, compareVersion), package_compareVersion1);
     stub.set(ADDR(Package, name), package_name);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
     stub.set(ADDR(Package, depends), deb_conflicts_null);
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), package_package);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
                                                              const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus_ok);
 
-    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList);
+    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList, QString());
     EXPECT_EQ("", debArch);
     EXPECT_EQ(2, choosed_set.size());
     EXPECT_EQ(1, cadicateList.size());
@@ -2099,21 +2123,23 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageCandidateChoose_3)
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
 
+    stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, installedVersion), package_version);
     stub.set(ADDR(Package, compareVersion), package_compareVersion2);
     stub.set(ADDR(Package, name), package_name);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
     stub.set(ADDR(Package, depends), deb_conflicts_null);
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), package_package);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy_error);
-
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy_error);
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
                                                              const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus_ok);
 
-    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList);
+    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList, QString());
     EXPECT_EQ("", debArch);
     EXPECT_EQ(0, choosed_set.size());
     EXPECT_EQ(1, cadicateList.size());
@@ -2132,21 +2158,24 @@ TEST_F(UT_packagesManager, PackageManager_UT_packageCandidateChoose_4)
 
     stub.set(ADDR(PackagesManager, packageWithArch), stub_avaialbe_packageWithArch);
 
+    stub.set(ADDR(Package, version), package_version);
     stub.set(ADDR(Package, installedVersion), package_version);
     stub.set(ADDR(Package, compareVersion), package_compareVersion1);
     stub.set(ADDR(Package, name), package_name);
     stub.set(ADDR(Package, architecture), package_architecture);
     stub.set(ADDR(Package, conflicts), package_conflicts);
+    stub.set(ADDR(Package, replaces), deb_replaces_null);
     stub.set(ADDR(Package, depends), deb_conflicts_null);
     stub.set((QApt::Package * (QApt::Backend::*)(const QString & name) const)ADDR(Backend, package), package_package);
 
-    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &))ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy_error);
+    stub.set((const ConflictResult(PackagesManager::*)(const QString &, const QList<QApt::DependencyItem> &, const QList<QApt::DependencyItem> &))
+            ADDR(PackagesManager, isConflictSatisfy), stub_isConflictSatisfy_error);
 
     stub.set((const PackageDependsStatus(PackagesManager::*)(QSet<QString> &, const QString &,
                                                              const QList<QApt::DependencyItem> &))
              ADDR(PackagesManager, checkDependsPackageStatus), stub_checkDependsPackageStatus_ok);
 
-    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList);
+    m_packageManager->packageCandidateChoose(choosed_set, debArch, cadicateList, QString());
     EXPECT_EQ("", debArch);
     EXPECT_EQ(1, choosed_set.size());
     EXPECT_EQ(1, cadicateList.size());
